@@ -5,5 +5,6 @@ __version__ = get_distribution('pandasgui').version
 # Imports
 from qtstylish.qtstylish import dark, light, ThemeSwitcher
 from qtstylish.demo_widget import DemoWidget
+from qtstylish.modern_window import ModernWindow
 
-__all__ = ["dark", "light", "ThemeSwitcher", "DemoWidget", "__version__"]
+__all__ = ["dark", "light", "ThemeSwitcher", "DemoWidget", "ModernWindow", "__version__"]
