@@ -5,7 +5,7 @@ from PyQt5.QtWidgets import *
 
 try:
     from pandasgui import show
-    from pandasgui.datasets import small, pokemon
+    from pandasgui.datasets import pokemon, mi_manufacturing
 except:
     pass
 
@@ -752,11 +752,16 @@ class DemoWidget(QtWidgets.QWidget):
 
         row += 1
         # QListWidget
+        widgets_layout.addWidget(QLabel("QTreeWidget"), row, 0)
+
         x = QListWidget()
         x.setEnabled(True)
         for a in range(10):
             x.addItem(f"Item-{a}")
         x.itemAt(0, 0).setCheckState(Qt.Checked)
+        for index in range(x.count()):
+            item = x.item(index)
+            item.setFlags(item.flags() | QtCore.Qt.ItemIsEditable)
         widgets_layout.addWidget(x, row, 1)
 
         x = QListWidget()
@@ -884,7 +889,7 @@ class DemoWidget(QtWidgets.QWidget):
         # Temp
 
         try:
-            self.gui = show(small, pokemon, settings={'block':False, 'theme':'classic'})
+            self.gui = show(pokemon, mi_manufacturing, settings={'block':False, 'theme':'classic'})
             self.tabs.addTab(self.gui, "PandasGUI")
         except:
             pass
